nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

LutInpMux

Struct LutInpMux 

#[repr(transparent)]
pub struct LutInpMux(pub u32);
LUTn input x MUX

Tuple Fields

0: u32

Implementations

Source

impl LutInpMux

pub const fn lutn_inpx(&self) -> LutnInpx

Selects the input source to be connected to LUT0 input0. For each LUT, the slot associated with the output from LUTn itself is tied low.

pub const fn set_lutn_inpx(&mut self, val: LutnInpx)

Selects the input source to be connected to LUT0 input0. For each LUT, the slot associated with the output from LUTn itself is tied low.