#[repr(transparent)]pub struct LutInpMux(pub u32);Expand description
LUTn input x MUX
Tuple Fields
0: u32Implementations
Sourceimpl LutInpMux
impl LutInpMux
Sourcepub const fn lutn_inpx(&self) -> LutnInpx
pub const fn lutn_inpx(&self) -> LutnInpx
Selects the input source to be connected to LUT0 input0. For each LUT, the slot associated with the output from LUTn itself is tied low.
Sourcepub const fn set_lutn_inpx(&mut self, val: LutnInpx)
pub const fn set_lutn_inpx(&mut self, val: LutnInpx)
Selects the input source to be connected to LUT0 input0. For each LUT, the slot associated with the output from LUTn itself is tied low.